gcsfs is a community maintained project. We welcome contributions in the form of bug reports, documentation, code, design proposals, and more.

## Project specific notes

For testing remote API calls this project uses [VCR](https://vcrpy.readthedocs.io/en/latest/). See the docs for more information https://gcsfs.readthedocs.io/en/latest/developer.html.
